Module cml

Module cml 

Bounded Chemical Markup Language (CML) previews.

CML represents molecules, reactions, spectra and related chemistry data in XML. This adapter exposes molecule/atom/bond structure and element counts without resolving dictionaries, conventions, URLs or performing chemistry.