Module html

Module html 

HTML document parser, typography typesetter, and paginated vector SVG renderer.

Parses HTML markup (headings, paragraphs, blockquotes, lists, tables, pre/code), performs flow-based line wrapping and page pagination, and renders standard vector SVG pages.

Structs

HtmlTextRun
HtmlTextStyle

Enums

HtmlBlock
HtmlTextBlockKind

Functions

decode_html_entities
parse_html_blocks