Bounded RFC 7396 JSON Merge Patch previews.
Merge Patch documents mimic a target JSON object: non-null members replace or merge values and null members remove them. This adapter renders affected paths, actions and value types only; it never applies a patch or displays value payloads.