Module subtitle

Module subtitle 

Bounded SubRip (SRT) and WebVTT subtitle previews.

Cue text and timing are rendered as inert text. No HTML, script, style, media, or external reference from a track is executed or fetched.