Module wig

Module wig 

Bounded UCSC Wiggle (.wig) continuous-signal preview.

The fixedStep and variableStep text forms are converted into inert interval rows. Coordinates remain one-based and fully closed as defined by UCSC; track/browser directives and remote track references are never evaluated.