Module xsd

Module xsd 

Bounded W3C XML Schema (XSD) previews.

XSD documents define elements and type components and may import other schemas. This adapter reports schema structure without fetching imports, validating instance documents or exposing schema documentation payloads.