pub fn layout_and_render_table(
table: &TableData,
_options: &ConvertOptions,
) -> Result<Page>Expand description
Computes column widths, row heights, and generates clean Page IR for the table.
pub fn layout_and_render_table(
table: &TableData,
_options: &ConvertOptions,
) -> Result<Page>Computes column widths, row heights, and generates clean Page IR for the table.