Module cif

Module cif 

Bounded mmCIF/PDBx atom-coordinate preview.

Extracts the atom_site loop from text CIF files and renders each model with the existing molecule renderer. Chemistry perception, symmetry, and other crystallographic metadata remain inert.