Bounded CloudEvents JSON 1.0 previews.
CloudEvents JSON envelopes carry event metadata and an optional data payload. This adapter renders only inert metadata (with URI query values masked): data, extension values and external schemas are summarized without being displayed, decoded, fetched, or executed.