Bounded Graph Modeling Language (GML) graph preview.
GML is a bracketed text graph format distinct from geographic GML XML.
This adapter accepts the common graph [ node [...] edge [...] ] subset,
preserving topology and labels while keeping arbitrary attributes inert.