pub fn convert_bytes<F>(
file_name: &str,
bytes: &[u8],
options: &ConvertOptions,
limits: ByteConvertLimits,
on_page: F,
) -> Result<ByteConversionReport>Expand description
Convert a supported document directly from memory and emit completed pages as soon as they are rendered. This API is designed for browser/WASM and server preview callers that should not need temporary files.