pub struct ConvertOptions {
pub max_input_bytes: u64,
pub max_zip_entry_bytes: u64,
pub max_pages: usize,
pub max_xml_events: usize,
pub include_metadata: bool,
pub precision: usize,
pub jobs: usize,
pub outline_embedded_pdf_text: bool,
}Fields
max_input_bytes: u64max_zip_entry_bytes: u64max_pages: usizemax_xml_events: usizeinclude_metadata: boolprecision: usizejobs: usizeoutline_embedded_pdf_text: boolRender embedded PDF fonts as exact glyph outlines instead of editable substitute-font text. This improves fidelity but requires the caller to verify the source font’s outline/embedding rights.